@@ -140,10 +140,11 @@ class ETA(object):
 
 
 class Seeder(object):
-    def __init__(self, cache, task, seed_pool):
+    def __init__(self, cache, task, seed_pool, skip_geoms_for_last_levels):
         self.cache = cache
         self.task = task
         self.seed_pool = seed_pool
+        self.skip_geoms_for_last_levels = skip_geoms_for_last_levels
         
         num_seed_levels = task.max_level - task.start_level + 1
         self.report_till_level = task.start_level + int(num_seed_levels * 0.7)
@@ -164,20 +165,19 @@ class Seeder(object):
                              intersections with bbox/geom
         """
         bbox_, tiles_, subtiles = self.grid.get_affected_level_tiles(cur_bbox, level)
-        subtiles = list(subtiles)
+
+        if level == self.task.max_level-self.skip_geoms_for_last_levels:
+            # do not filter in last levels
+            all_subtiles = True
+        sub_seeds, total_sub_seeds = self._filter_subtiles(subtiles, all_subtiles)
+        
         if level <= self.report_till_level:
             self.report_progress(level, cur_bbox)
         
-        if level == self.task.max_level-1:
-            # do not filter in last levels
-            all_subtiles = True
-        
         if level < self.task.max_level:
-            sub_seeds = self._sub_seeds(subtiles, all_subtiles)
             if sub_seeds:
                 progress = progress / len(sub_seeds)
-                total_sub_seeds = len(sub_seeds)
-                for i, (sub_bbox, intersection) in enumerate(sub_seeds):
+                for i, (subtile_, sub_bbox, intersection) in enumerate(sub_seeds):
                     sub_bbox = limit_sub_bbox(cur_bbox, sub_bbox)
                     cur_progess_str = progess_str + status_symbol(i, total_sub_seeds)
                     all_subtiles = True if intersection == CONTAINS else False
@@ -188,19 +188,18 @@ class Seeder(object):
         
         self.eta.update(self.progress)
         
-        not_cached_tiles = self.not_cached(subtiles)
+        not_cached_tiles = self.not_cached(sub_seeds)
         if not_cached_tiles:
             self.count += len(not_cached_tiles)
             self.seed_pool.seed(not_cached_tiles,
                 (progess_str, self.progress, self.eta))
         
-        return subtiles
+        return sub_seeds
     
     def not_cached(self, tiles):
-        return [tile for tile in tiles
+        return [tile for tile, _bbox, _intersection in tiles
                     if tile is not None and
                         not self.cache.cache_mgr.is_cached(tile)]
-
     
     def report_progress(self, level, bbox):
         print '[%s] %2s %6.2f%% %s (#%d) ETA: %s' % (
@@ -208,30 +207,35 @@ class Seeder(object):
             format_bbox(bbox), self.count, self.eta)
         sys.stdout.flush()
     
-    def _sub_seeds(self, subtiles, all_subtiles):
+    def _filter_subtiles(self, subtiles, all_subtiles):
         """
         Return all sub tiles that intersect the 
         """
         sub_seeds = []
+        total_sub_seeds = 0
         for subtile in subtiles:
+            total_sub_seeds += 1
             if subtile is None: continue
             sub_bbox = self.grid.meta_bbox(subtile)
             intersection = CONTAINS if all_subtiles else self.task.intersects(sub_bbox)
             if intersection:
-                sub_seeds.append((sub_bbox, intersection))
-        return sub_seeds
+                sub_seeds.append((subtile, sub_bbox, intersection))
+        return sub_seeds, total_sub_seeds
+    
 
 
 class CacheSeeder(object):
     """
     Seed multiple caches with the same option set.
     """
-    def __init__(self, caches, remove_before, dry_run=False, concurrency=2):
+    def __init__(self, caches, remove_before, dry_run=False, concurrency=2,
+                 skip_geoms_for_last_levels=0):
         self.remove_before = remove_before
         self.dry_run = dry_run
         self.caches = caches
         self.concurrency = concurrency
         self.seeded_caches = []
+        self.skip_geoms_for_last_levels = skip_geoms_for_last_levels
     
     def seed_view(self, bbox, level, srs, cache_srs, geom=None):
         for cache in self.caches:
@@ -242,7 +246,7 @@ class CacheSeeder(object):
                     cache.cache_mgr._expire_timestamp = self.remove_before
                 seed_pool = SeedPool(cache, dry_run=self.dry_run, size=self.concurrency)
                 seed_task = SeedTask(bbox, level, srs, cache.grid.srs, geom)
-                seeder = Seeder(cache, seed_task, seed_pool)
+                seeder = Seeder(cache, seed_task, seed_pool, self.skip_geoms_for_last_levels)
                 seeder.seed()
                 seed_pool.stop()
     
@@ -334,8 +338,8 @@ def status_symbol(i, total):
     else:
         return symbols[int(math.ceil(i/(total/4)))]
 
-def seed_from_yaml_conf(conf_file, verbose=True, rebuild_inplace=True, dry_run=False,
-    concurrency=2):
+def seed_from_yaml_conf(conf_file, verbose=True, dry_run=False,
+    concurrency=2, skip_geoms_for_last_levels=0):
     from mapproxy.core.conf_loader import load_services
     
     if hasattr(conf_file, 'read'):
@@ -356,7 +360,8 @@ def seed_from_yaml_conf(conf_file, verbose=True, rebuild_inplace=True, dry_run=F
         remove_before = before_timestamp_from_options(options)
         caches = caches_from_layer(server.layers[layer])
         seeder = CacheSeeder(caches, remove_before=remove_before, dry_run=dry_run,
-                            concurrency=concurrency)
+                            concurrency=concurrency,
+                            skip_geoms_for_last_levels=skip_geoms_for_last_levels)
         for view in options['views']:
             view_conf = seed_conf['views'][view]
             if 'ogr_datasource' in view_conf:
