@@ -14,16 +14,18 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import division, with_statement
 from mapproxy.core.image import ImageSource, ImageTransformer
 from mapproxy.core.client import retrieve_url, HTTPClientError
 from mapproxy.core.srs import SRS, make_lin_transf
+from mapproxy.core.utils import NullLock
 
 class WMSClient(object):
     """
     Client for WMS requests.
     """
     def __init__(self, request_template=None, client_request=None, http_client=None,
-        supported_srs=None):
+        supported_srs=None, lock=None):
         """
         :param request_template: a request that will be used as a template for
             new requests
@@ -37,9 +39,10 @@ class WMSClient(object):
         self.request_template = request_template
         self.http_client = http_client
         self.supported_srs = supported_srs
+        self.lock = lock or NullLock
 
     def get_map(self, request):
-        if self.supported_srs and request.params.srs not in self.supported_srs:
+        if self.supported_srs and SRS(request.params.srs) not in self.supported_srs:
             return self._transformed_get_map(request)
         
         resp = self._retrieve_url(self._map_url(request))
@@ -53,18 +56,29 @@ class WMSClient(object):
         dst_bbox = request.params.bbox
         src_bbox = dst_srs.transform_bbox_to(src_srs, dst_bbox)
         
+        src_width, src_height = src_bbox[2]-src_bbox[0], src_bbox[3]-src_bbox[1]
+        ratio = src_width/src_height
+
+        dst_size = request.params.size
+        
+        xres, yres = src_width/dst_size[0], src_height/dst_size[1]
+        if xres < yres:
+            src_size = dst_size[0], int(dst_size[0]/ratio + 0.5)
+        else:
+            src_size = int(dst_size[1]*ratio +0.5), dst_size[1]
+        
+        request = request.copy()
         request.params['srs'] = src_srs.srs_code
         request.params.bbox = src_bbox
+        request.params.size = src_size
         
         resp = self._retrieve_url(self._map_url(request))
         
-        img = ImageSource(resp, request.params.format, size=request.params.size)
-        
+        img = ImageSource(resp, request.params.format, size=src_size)
         img = ImageTransformer(src_srs, dst_srs).transform(img, src_bbox, 
-            request.params.size, dst_bbox)
+            dst_size, dst_bbox)
         
         img.format = self.request_template.params.format
-        
         return img
     
     def _best_supported_srs(self, srs):
@@ -85,9 +99,10 @@ class WMSClient(object):
         return resp.read()
     
     def _retrieve_url(self, url):
-        if self.http_client:
-            return self.http_client.open(url)
-        return retrieve_url(url)
+        with self.lock():
+            if self.http_client:
+                return self.http_client.open(url)
+            return retrieve_url(url)
     
     def _info_url(self, request):
         req = self.client_request(self.request_template, request)
