@@ -29,25 +29,37 @@ from mapproxy.core.config import base_config
 env = Environment(loader=PackageLoader('mapproxy.wms', 'templates'),
                   trim_blocks=True)
 
+import logging
+log = logging.getLogger(__name__)
+
 class WMSServer(Server):
     names = ('service',)
     request_methods = ('map', 'capabilities', 'featureinfo')
     
-    def __init__(self, layers, md, layer_merger=None, request_parser=None):
+    def __init__(self, layers, md, layer_merger=None, request_parser=None, tile_layers=None):
         Server.__init__(self)
         self.request_parser = request_parser or wms_request
         self.layers = layers
+        self.tile_layers = tile_layers or {}
         if layer_merger is None:
             from mapproxy.core.image import LayerMerger
             layer_merger = LayerMerger
         self.merger = layer_merger
         self.md = md
-        
+                
     def map(self, map_request):
         merger = self.merger()
         self.check_request(map_request)
-        for layer in map_request.params.layers:
-            merger.add(self.layers[layer].render(map_request))
+        
+        render_layers = []
+        for layer_name in map_request.params.layers:
+            layer = self.layers[layer_name]
+            if not layer.transparent:
+                render_layers = []
+            render_layers.append(layer)
+        
+        for layer in render_layers:
+            merger.add(layer.render(map_request))
         params = map_request.params
         result = merger.merge(params.format, params.size,
                               bgcolor=params.bgcolor,
@@ -60,9 +72,13 @@ class WMSServer(Server):
         else:
             layers = [layer for name, layer in self.layers.iteritems()
                       if name != '__debug__']
-            
+        
+        if map_request.params.get('tiled', 'false').lower() == 'true':
+            tile_layers = self.tile_layers.values()
+        else:
+            tile_layers = []
         service = self._service_md(map_request)
-        result = Capabilities(service, layers).render(map_request)
+        result = Capabilities(service, layers, tile_layers).render(map_request)
         return Response(result, mimetype=map_request.mime_type)
     
     def featureinfo(self, request):
@@ -78,7 +94,11 @@ class WMSServer(Server):
                 infos.append(info)
             else:
                 [infos.append(i) for i in info if i is not None]
-        return Response('\n'.join(infos), mimetype='text/plain')
+        if 'info_format' in request.params:
+            mimetype = request.params.info_format
+        else:
+            mimetype = 'text/plain'
+        return Response('\n'.join(infos), mimetype=mimetype)
     
     def check_request(self, request):
         query_layers = request.params.query_layers if hasattr(request, 'query_layers') else []
@@ -96,20 +116,22 @@ class Capabilities(object):
     """
     Renders WMS capabilities documents.
     """
-    def __init__(self, server_md, layer_md):
+    def __init__(self, server_md, layers, tile_layers):
         self.service = server_md
-        self.layers = layer_md
+        self.layers = layers
+        self.tile_layers = tile_layers
     
     def render(self, _map_request):
         return self._render_template(_map_request.capabilities_template)
     
     def _render_template(self, template):
         template = env.get_template(template)
-        server_bbox = self._create_server_bbox()
+        server_bbox = self._create_server_bbox()        
         return template.render(service=self.service, layers=self.layers,
                                server_llbbox=server_bbox,
                                formats=base_config().wms.image_formats,
-                               srs=base_config().wms.srs)
+                               srs=base_config().wms.srs,
+                               tile_layers=self.tile_layers)
     
     def _create_server_bbox(self):
         bbox = self.layers[0].llbbox
